/// <reference types="google.maps" />

import * as react from 'react';
import { RefCallback, ReactElement } from 'react';

type OverlayViewProps = {
    /**
     * Specifies which map pane to use for this overlay.
     * @see [link](https://developers.google.com/maps/documentation/javascript/reference/overlay-view#MapPanes)
     * @default 'overlayMouseTarget'
     */
    mapPaneLayer?: keyof google.maps.MapPanes;
    /**
     * stops click, tap, drag, and wheel events on the element from bubbling up to the map. Use this to prevent map dragging and zooming, as well as map `"click"` events
     */
    preventMapHitsAndGestures?: boolean;
    /**
     * stops click or tap on the element from bubbling up to the map. Use this to prevent the map from triggering `"click"` events
     */
    preventMapHits?: boolean;
    /**
     * [render](https://react.dev/reference/react/cloneElement#passing-data-with-a-render-prop) prop, a function that returns a React element and provides the ability to attach {@link ref} to it
     */
    render(ref: RefCallback<HTMLElement>): ReactElement;
    lat: number;
    lng: number;
};
declare const OverlayView: react.ForwardRefExoticComponent<OverlayViewProps & react.RefAttributes<HTMLElement>>;

export { type OverlayViewProps, OverlayView as default };
